@@ -10,5 +10,11 @@ module MsRestAzure
 
     # @return [String] identificator of the request.
     attr_accessor :request_id
+
+    # @return [String] Correlation Id of the request.
+    attr_accessor :correlation_request_id
+
+    # @return [String] Client Request Id of the request.
+    attr_accessor :client_request_id
   end
 end
